@@ -445,8 +445,10 @@ class Base(unittest.TestCase):
 
             return soup
             
-        except WebDriverException:
-            pass
+        except WebDriverException as e:
+            self.driver.switch_to.default_content()
+            soup = BeautifulSoup(self.driver.page_source,"html.parser")
+            return soup
 
     def get_element_text(self, element):
         """
@@ -975,7 +977,7 @@ class Base(unittest.TestCase):
         if not self.config.browser.lower() == "electron":
             if self.config.headless:
                 self.driver.set_window_position(0, 0)
-                self.driver.set_window_size(1024, 768)
+                self.driver.set_window_size(1366, 768)
             else:
                 self.driver.maximize_window()
                    
